==> peony-3.1.0-1.src.tar.gz: peony-3.1.0/translations/peony-qt-desktop/peony-qt-desktop_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Peony::DesktopIconView</name>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.h" line="80"/>
        <source>Desktop Icon View</source>
        <translation>桌面图标视图</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="559"/>
        <source>New Folder</source>
        <translation>新建文件夹</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="641"/>
        <source>set background</source>
        <translation>设置背景</translation>
    </message>
    <message>
        <source>Delete file Warning</source>
        <translation type="vanished">删除文件警告</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="821"/>
        <source>Open failed</source>
        <translation>打开失败</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="822"/>
        <source>Open directory failed, you have no permission!</source>
        <translation>打开文件夹失败，您没有该目录的权限！</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="805"/>
        <source>Open Link failed</source>
        <translation>打开快捷方式失败</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="806"/>
        <source>File not exist, do you want to delete the link file?</source>
        <translation>目标文件夹不存在，是否删除该无效快捷方式？</translation>
    </message>
</context>
<context>
    <name>Peony::DesktopMenu</name>
    <message>
        <source>&amp;Open in new Window</source>
        <translation type="vanished">在新窗口中打开(&amp;N)</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation type="vanished">全选(&amp;A)</translation>
    </message>
    <message>
        <source>&amp;Open &quot;%1&quot;</source>
        <translation type="vanished">打开 &quot;%1&quot;(&amp;O)</translation>
    </message>
    <message>
        <source>Open &quot;%1&quot; &amp;with...</source>
        <translation type="vanished">打开方式(&amp;W)...</translation>
    </message>
    <message>
        <source>&amp;More applications...</source>
        <translation type="vanished">更多应用(&amp;M)...</translation>
    </message>
    <message>
        <source>Open &quot;%1&quot; with...</source>
        <translation type="vanished">打开方式...</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation type="vanished">打开(&amp;O)</translation>
    </message>
    <message>
        <source>Open &amp;with...</source>
        <translation type="vanished">打开方式(&amp;W)...</translation>
    </message>
    <message>
        <source>&amp;Open %1 selected files</source>
        <translation type="vanished">打开%1个选中文件(&amp;O)</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="228"/>
        <source>Reverse Select</source>
        <translation>反选</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation type="vanished">新建(&amp;N)</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="242"/>
        <source>New...</source>
        <translation>新建...</translation>
    </message>
    <message>
        <source>Empty &amp;File</source>
        <translation type="vanished">空文件(&amp;E)</translation>
    </message>
    <message>
        <source>&amp;Folder</source>
        <translation type="vanished">文件夹(&amp;F)</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="319"/>
        <source>New Folder</source>
        <translation>新建文件夹</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="336"/>
        <source>View Type...</source>
        <translation>视图类型...</translation>
    </message>
    <message>
        <source>&amp;Small</source>
        <translation type="vanished">小图标(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation type="vanished">中图标(&amp;N)</translation>
    </message>
    <message>
        <source>&amp;Large</source>
        <translation type="vanished">大图标(&amp;L)</translation>
    </message>
    <message>
        <source>&amp;Huge</source>
        <translation type="vanished">超大图标(&amp;H)</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="109"/>
        <source>Open in new Window</source>
        <translation>在新窗口中打开</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="114"/>
        <source>Select All</source>
        <translation>全选</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="137"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="165"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="190"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="201"/>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="145"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="170"/>
        <source>Open with...</source>
        <translation>打开方式</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="158"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="184"/>
        <source>More applications...</source>
        <translation>更多应用</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="204"/>
        <source>Open %1 selected files</source>
        <translation>打开%1个选中文件</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="305"/>
        <source>Empty File</source>
        <translation>空文件</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="315"/>
        <source>Folder</source>
        <translation>文件夹</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="342"/>
        <source>Small</source>
        <translation>小图标</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="347"/>
        <source>Normal</source>
        <translation>中图标</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="352"/>
        <source>Large</source>
        <translation>大图标</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="357"/>
        <source>Huge</source>
        <translation>超大图标</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="387"/>
        <source>Sort By...</source>
        <translation>排序方式...</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="392"/>
        <source>Name</source>
        <translation>文件名称</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="394"/>
        <source>File Type</source>
        <translation>文件类型</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="395"/>
        <source>File Size</source>
        <translation>文件大小</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="467"/>
        <source>Clean the trash</source>
        <translation>清空回收站</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="481"/>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="491"/>
        <source>Delete to trash</source>
        <translation>删除到回收站</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">错误</translation>
    </message>
    <message>
        <source>Can not show trash properties with other files together!</source>
        <translation type="vanished">不能将回收站与其他文件一起查看属性!</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="393"/>
        <source>Modified Date</source>
        <translation>修改日期</translation>
    </message>
    <message>
        <source>Delete file Warning</source>
        <translation type="vanished">删除文件警告</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="485"/>
        <source>Cut</source>
        <translation>剪切</translation>
    </message>
    <message>
        <source>&amp;Delete to trash</source>
        <translation type="vanished">删除到回收站(&amp;D)</translation>
    </message>
    <message>
        <source>Delete forever</source>
        <translation type="vanished">永久删除</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="504"/>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="511"/>
        <source>Paste</source>
        <translation>粘贴</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="517"/>
        <source>Refresh</source>
        <translation>刷新</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="531"/>
        <source>Properties</source>
        <translation>属性</translation>
    </message>
    <message>
        <source>P&amp;roperties</source>
        <translation type="vanished">属性(&amp;R)</translation>
    </message>
    <message>
        <source>Sort Order...</source>
        <translation type="vanished">排列顺序...</translation>
    </message>
    <message>
        <source>Ascending Order</source>
        <translation type="vanished">升序</translation>
    </message>
    <message>
        <source>Descending Order</source>
        <translation type="vanished">降序</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation type="vanished">放大(&amp;I)</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation type="vanished">缩小(&amp;O)</translation>
    </message>
    <message>
        <source>&amp;Restore all</source>
        <translation type="vanished">恢复全部(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Clean the trash</source>
        <translation type="vanished">清空回收站(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="469"/>
        <source>Delete Permanently</source>
        <translation>永久删除</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="469"/>
        <source>Are you sure that you want to delete these files? Once you start a deletion, the files deleting will never be restored again.</source>
        <translation>您确定要删除这些文件吗？一旦开始删除，这些文件将不可再恢复。</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="vanished">复制(&amp;C)</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation type="vanished">剪切(&amp;T)</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="vanished">删除(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation type="vanished">重命名(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation type="vanished">粘贴(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Refresh</source>
        <translation type="vanished">刷新(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Properties</source>
        <translation type="vanished">属性(&amp;P)</translation>
    </message>
</context>
<context>
    <name>Peony::DesktopWindow</name>
    <message>
        <location filename="../../peony-qt-desktop/desktop-window.cpp" line="96"/>
        <source>Desktop</source>
        <translation>桌面</translation>
    </message>
    <message>
        <source>set background</source>
        <translation type="vanished">设置壁纸</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation type="vanished">新建文件夹</translation>
    </message>
</context>
<context>
    <name>PeonyDesktopApplication</name>
    <message>
        <source>Close the peony-qt desktop window</source>
        <translation type="vanished">关闭桌面并退出</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="151"/>
        <source>peony-qt-desktop</source>
        <translation>桌面</translation>
    </message>
    <message>
        <source>Peony-Qt Desktop</source>
        <translation type="vanished">桌面</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation type="vanished">桌面</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="253"/>
        <source>Close the peony desktop window</source>
        <translation>关闭桌面程序</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="256"/>
        <source>Take over the dbus service.</source>
        <translation>接管DBus服务。</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="259"/>
        <source>Take over the desktop displaying</source>
        <translation>接管桌面</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="350"/>
        <source>set background</source>
        <translation>设置背景</translation>
    </message>
</context>
</TS>

==> peony-3.2.4-1.src.tar.gz: peony-3.2.4/translations/peony-qt-desktop/peony-qt-desktop_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Peony::DesktopIconView</name>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.h" line="81"/>
        <source>Desktop Icon View</source>
        <translation>桌面图标视图</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="575"/>
        <source>New Folder</source>
        <translation>新建文件夹</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="667"/>
        <source>set background</source>
        <translation>设置背景</translation>
    </message>
    <message>
        <source>Delete file Warning</source>
        <translation type="vanished">删除文件警告</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="900"/>
        <source>Open failed</source>
        <translation>打开失败</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="901"/>
        <source>Open directory failed, you have no permission!</source>
        <translation>打开文件夹失败，您没有该目录的权限！</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="884"/>
        <source>Open Link failed</source>
        <translation>打开快捷方式失败</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-icon-view.cpp" line="885"/>
        <source>File not exist, do you want to delete the link file?</source>
        <translation>目标文件夹不存在，是否删除该无效快捷方式？</translation>
    </message>
</context>
<context>
    <name>Peony::DesktopItemModel</name>
    <message>
        <location filename="../../peony-qt-desktop/desktop-item-model.cpp" line="552"/>
        <source>Computer</source>
        <translation>计算机</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-item-model.cpp" line="554"/>
        <source>Trash</source>
        <translation>回收站</translation>
    </message>
</context>
<context>
    <name>Peony::DesktopMenu</name>
    <message>
        <source>&amp;Open in new Window</source>
        <translation type="vanished">在新窗口中打开(&amp;N)</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation type="vanished">全选(&amp;A)</translation>
    </message>
    <message>
        <source>&amp;Open &quot;%1&quot;</source>
        <translation type="vanished">打开 &quot;%1&quot;(&amp;O)</translation>
    </message>
    <message>
        <source>Open &quot;%1&quot; &amp;with...</source>
        <translation type="vanished">打开方式(&amp;W)...</translation>
    </message>
    <message>
        <source>&amp;More applications...</source>
        <translation type="vanished">更多应用(&amp;M)...</translation>
    </message>
    <message>
        <source>Open &quot;%1&quot; with...</source>
        <translation type="vanished">打开方式...</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation type="vanished">打开(&amp;O)</translation>
    </message>
    <message>
        <source>Open &amp;with...</source>
        <translation type="vanished">打开方式(&amp;W)...</translation>
    </message>
    <message>
        <source>&amp;Open %1 selected files</source>
        <translation type="vanished">打开%1个选中文件(&amp;O)</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="237"/>
        <source>Reverse Select</source>
        <translation>反选</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation type="vanished">新建(&amp;N)</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="251"/>
        <source>New...</source>
        <translation>新建...</translation>
    </message>
    <message>
        <source>Empty &amp;File</source>
        <translation type="vanished">空文件(&amp;E)</translation>
    </message>
    <message>
        <source>&amp;Folder</source>
        <translation type="vanished">文件夹(&amp;F)</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="334"/>
        <source>New Folder</source>
        <translation>新建文件夹</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="351"/>
        <source>View Type...</source>
        <translation>视图类型...</translation>
    </message>
    <message>
        <source>&amp;Small</source>
        <translation type="vanished">小图标(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation type="vanished">中图标(&amp;N)</translation>
    </message>
    <message>
        <source>&amp;Large</source>
        <translation type="vanished">大图标(&amp;L)</translation>
    </message>
    <message>
        <source>&amp;Huge</source>
        <translation type="vanished">超大图标(&amp;H)</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="109"/>
        <source>Open in new Window</source>
        <translation>在新窗口中打开</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="114"/>
        <source>Select All</source>
        <translation>全选</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="137"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="165"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="199"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="210"/>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="145"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="170"/>
        <source>Open with...</source>
        <translation>打开方式</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="158"/>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="193"/>
        <source>More applications...</source>
        <translation>更多应用</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="213"/>
        <source>Open %1 selected files</source>
        <translation>打开%1个选中文件</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="320"/>
        <source>Empty File</source>
        <translation>空文本</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="330"/>
        <source>Folder</source>
        <translation>文件夹</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="357"/>
        <source>Small</source>
        <translation>小图标</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="362"/>
        <source>Normal</source>
        <translation>中图标</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="367"/>
        <source>Large</source>
        <translation>大图标</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="372"/>
        <source>Huge</source>
        <translation>超大图标</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="402"/>
        <source>Sort By...</source>
        <translation>排序方式...</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="407"/>
        <source>Name</source>
        <translation>文件名称</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="409"/>
        <source>File Type</source>
        <translation>文件类型</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="410"/>
        <source>File Size</source>
        <translation>文件大小</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="482"/>
        <source>Clean the trash</source>
        <translation>清空回收站</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="496"/>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="521"/>
        <source>Delete to trash</source>
        <translation>删除到回收站</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">错误</translation>
    </message>
    <message>
        <source>Can not show trash properties with other files together!</source>
        <translation type="vanished">不能将回收站与其他文件一起查看属性!</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="408"/>
        <source>Modified Date</source>
        <translation>修改日期</translation>
    </message>
    <message>
        <source>Delete file Warning</source>
        <translation type="vanished">删除文件警告</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="500"/>
        <source>Cut</source>
        <translation>剪切</translation>
    </message>
    <message>
        <source>&amp;Delete to trash</source>
        <translation type="vanished">删除到回收站(&amp;D)</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="530"/>
        <source>Delete forever</source>
        <translation>永久删除</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="538"/>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="545"/>
        <source>Paste</source>
        <translation>粘贴</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="551"/>
        <source>Refresh</source>
        <translation>刷新</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="565"/>
        <source>Properties</source>
        <translation>属性</translation>
    </message>
    <message>
        <source>P&amp;roperties</source>
        <translation type="vanished">属性(&amp;R)</translation>
    </message>
    <message>
        <source>Sort Order...</source>
        <translation type="vanished">排列顺序...</translation>
    </message>
    <message>
        <source>Ascending Order</source>
        <translation type="vanished">升序</translation>
    </message>
    <message>
        <source>Descending Order</source>
        <translation type="vanished">降序</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation type="vanished">放大(&amp;I)</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation type="vanished">缩小(&amp;O)</translation>
    </message>
    <message>
        <source>&amp;Restore all</source>
        <translation type="vanished">恢复全部(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Clean the trash</source>
        <translation type="vanished">清空回收站(&amp;C)</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="484"/>
        <source>Delete Permanently</source>
        <translation>永久删除</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/desktop-menu.cpp" line="484"/>
        <source>Are you sure that you want to delete these files? Once you start a deletion, the files deleting will never be restored again.</source>
        <translation>您确定要删除这些文件吗？一旦开始删除，这些文件将不可再恢复。</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="vanished">复制(&amp;C)</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation type="vanished">剪切(&amp;T)</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="vanished">删除(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation type="vanished">重命名(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation type="vanished">粘贴(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Refresh</source>
        <translation type="vanished">刷新(&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Properties</source>
        <translation type="vanished">属性(&amp;P)</translation>
    </message>
</context>
<context>
    <name>Peony::DesktopWindow</name>
    <message>
        <source>Desktop</source>
        <translation type="vanished">桌面</translation>
    </message>
    <message>
        <source>set background</source>
        <translation type="vanished">设置壁纸</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation type="vanished">新建文件夹</translation>
    </message>
</context>
<context>
    <name>PeonyDesktopApplication</name>
    <message>
        <source>Close the peony-qt desktop window</source>
        <translation type="vanished">关闭桌面并退出</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="169"/>
        <source>peony-qt-desktop</source>
        <translation>桌面</translation>
    </message>
    <message>
        <source>Peony-Qt Desktop</source>
        <translation type="vanished">桌面</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation type="vanished">桌面</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="371"/>
        <source>Close the peony desktop window</source>
        <translation>关闭桌面程序</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="374"/>
        <source>Take over the dbus service.</source>
        <translation>接管DBus服务。</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="377"/>
        <source>Take over the desktop displaying</source>
        <translation>接管桌面</translation>
    </message>
    <message>
        <location filename="../../peony-qt-desktop/peony-desktop-application.cpp" line="380"/>
        <source>Setup backgrounds</source>
        <translation>Setup backgrounds</translation>
    </message>
    <message>
        <source>set background</source>
        <translation type="vanished">设置背景</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../peony-qt-desktop/desktopbackgroundwindow.cpp" line="57"/>
        <source>set background</source>
        <translation>设置背景</translation>
    </message>
</context>
</TS>
